@@ -354,7 +354,7 @@ namespace Oxygen
 
                 } else if( !( respectWindowState && maximized )) {
 
-                    border = TFRAMESIZE;
+                    border = Metrics::TitleBar_TopMargin;
 
                 }
 
@@ -442,7 +442,7 @@ namespace Oxygen
                 titleRect.setRight( widget()->rect().right() - layoutMetric( LM_OuterPaddingRight ) );
             }
 
-            const QRect textRect( titleBoundingRect( options()->font( true, false),  titleRect, caption() ) );
+            const QRect textRect( titleBoundingRect( options()->font( true, false ),  titleRect, caption() ) );
             titleRect.setLeft( textRect.left() - layoutMetric( LM_TitleBorderLeft ) );
             titleRect.setRight( textRect.right() + layoutMetric( LM_TitleBorderRight ) );
 
@@ -608,10 +608,31 @@ namespace Oxygen
     QColor Client::titlebarTextColor(const QPalette &palette) const
     {
         if( glowIsAnimated() ) return KColorUtils::mix(
-            titlebarTextColor( palette, false ),
-            titlebarTextColor( palette, true ),
+            titlebarTextColor( palette, false, true ),
+            titlebarTextColor( palette, true, true ),
             glowIntensity() );
-        else return titlebarTextColor( palette, isActive() );
+        else return titlebarTextColor( palette, isActive(), true );
+    }
+
+    //_________________________________________________________
+    QColor Client::titlebarTextColor(const QPalette &palette, bool windowActive, bool itemActive ) const
+    {
+        if( itemActive )
+        {
+            return windowActive ?
+                palette.color(QPalette::Active, QPalette::WindowText):
+                helper().inactiveTitleBarTextColor( palette );
+
+        } else if( _configuration->drawTitleOutline() ) {
+
+            return options()->color( KDecoration::ColorFont, windowActive );
+
+        } else {
+
+            return helper().inactiveTitleBarTextColor( palette );
+
+        }
+
     }
 
     //_________________________________________________________
@@ -685,7 +706,7 @@ namespace Oxygen
         r.adjust(0,0, 1, 1);
 
         // base color
-        QColor color( palette.window().color() );
+        QColor color( palette.color( QPalette::Window ) );
 
         // add alpha channel
         if( _itemData.count() == 1 && glowIsAnimated() )
@@ -723,7 +744,7 @@ namespace Oxygen
             if( _configuration->drawTitleOutline() && ( isActive() || glowIsAnimated() ) && !isMaximized() )
             {
                 if( _configuration->frameBorder() == Configuration::BorderTiny ) rect.adjust( 1, 0, -1, 0 );
-                else if( _configuration->frameBorder() > Configuration::BorderTiny ) rect.adjust( HFRAMESIZE-1, 0, -HFRAMESIZE+1, 0 );
+                else if( _configuration->frameBorder() > Configuration::BorderTiny ) rect.adjust( Metrics::TitleBar_OutlineMargin-1, 0, -Metrics::TitleBar_OutlineMargin+1, 0 );
             }
 
             if( rect.isValid() )
@@ -744,12 +765,12 @@ namespace Oxygen
             QRect frame;
 
             // bottom line
-            const int leftOffset = qMin( layoutMetric( LM_BorderLeft ), int(HFRAMESIZE) );
-            const int rightOffset = qMin( layoutMetric( LM_BorderRight ), int(HFRAMESIZE) );
+            const int leftOffset = qMin( layoutMetric( LM_BorderLeft ), int(Metrics::TitleBar_OutlineMargin) );
+            const int rightOffset = qMin( layoutMetric( LM_BorderRight ), int(Metrics::TitleBar_OutlineMargin) );
             if( _configuration->frameBorder() > Configuration::BorderNone )
             {
 
-                const int height = qMax( 0, layoutMetric( LM_BorderBottom ) - HFRAMESIZE );
+                const int height = qMax( 0, layoutMetric( LM_BorderBottom ) - Metrics::TitleBar_OutlineMargin );
                 const int width = r.width() - leftOffset - rightOffset - 1;
 
                 const QRect rect( r.bottomLeft()-position + QPoint( leftOffset, -layoutMetric( LM_BorderBottom ) ), QSize( width, height ) );
@@ -763,7 +784,7 @@ namespace Oxygen
 
             // left and right
             const int topOffset = titleHeight;
-            const int bottomOffset = qMin( layoutMetric( LM_BorderBottom ), int(HFRAMESIZE) );
+            const int bottomOffset = qMin( layoutMetric( LM_BorderBottom ), int(Metrics::TitleBar_OutlineMargin) );
             const int height = r.height() - topOffset - bottomOffset - 1;
 
             if( _configuration->frameBorder() >= Configuration::BorderTiny )
@@ -773,14 +794,14 @@ namespace Oxygen
                 painter->setPen( shadow );
 
                 // left
-                int width = qMax( 0, layoutMetric( LM_BorderLeft ) - HFRAMESIZE );
+                int width = qMax( 0, layoutMetric( LM_BorderLeft ) - Metrics::TitleBar_OutlineMargin );
                 QRect rect( r.topLeft()-position + QPoint( layoutMetric( LM_BorderLeft ) - width, topOffset ), QSize( width, height ) );
                 if( width > 0 ) { mask += rect; frame |= rect; }
 
                 painter->drawLine( rect.topLeft()-QPoint(1,0), rect.bottomLeft()-QPoint(1, 0) );
 
                 // right
-                width = qMax( 0, layoutMetric( LM_BorderRight ) - HFRAMESIZE );
+                width = qMax( 0, layoutMetric( LM_BorderRight ) - Metrics::TitleBar_OutlineMargin );
                 rect = QRect(r.topRight()-position + QPoint( -layoutMetric( LM_BorderRight ), topOffset ), QSize( width, height ));
                 if( width > 0 ) { mask += rect; frame |= rect; }
 
@@ -1045,26 +1066,16 @@ namespace Oxygen
         if( itemCount == 1 )
         {
 
-            // no title outline if the window caption is empty
-            if( !caption.trimmed().isEmpty() )
-            {
-                if( _itemData.isAnimated() ) {
+            /*
+             * render outline if
+             * - caption is not empty
+             * - item is animated (because of tabbing)
+             * - window is active or glow-animated and titleoutlines are to be drawn
+             */
 
-                    renderTitleOutline( painter, item._boundingRect, palette );
-
-                } else if( (isActive()||glowIsAnimated()) && _configuration->drawTitleOutline() ) {
-
-                    // adjusts boundingRect accordingly
-                    QRect boundingRect( item._boundingRect );
-                    boundingRect.setLeft( textRect.left() - layoutMetric( LM_TitleBorderLeft ) );
-                    boundingRect.setRight( textRect.right() + layoutMetric( LM_TitleBorderRight ) );
-
-                    // render bounding rect around it with extra margins
-                    renderTitleOutline( painter, boundingRect, palette );
-
-                }
-
-            }
+            if( !caption.trimmed().isEmpty() &&
+                ( _itemData.isAnimated() || ( (isActive()||glowIsAnimated()) && _configuration->drawTitleOutline() ) ) )
+            { renderTitleOutline( painter, item._boundingRect, palette ); }
 
         } else if( active ) {
 
@@ -1095,7 +1106,7 @@ namespace Oxygen
             // otherwise current caption is rendered directly
             renderTitleText(
                 painter, textRect, caption,
-                titlebarTextColor( backgroundPalette( widget(), palette ), false ),
+                titlebarTextColor( backgroundPalette( widget(), palette ), isActive(), false ),
                 titlebarContrastColor( background ) );
 
         }
@@ -1106,7 +1117,7 @@ namespace Oxygen
 
             // separators
             // draw Left separator
-            const QColor color( backgroundPalette( widget(), palette ).window().color() );
+            const QColor color( backgroundPalette( widget(), palette ).color( QPalette::Window ) );
             const bool isFirstItem(  index == 0 || (index == 1 && !_itemData[0]._boundingRect.isValid() ) );
             if( !active && ( ( isFirstItem && buttonsLeftWidth() > 0 ) || _itemData.isTarget( index ) ) )
             {
@@ -1309,11 +1320,15 @@ namespace Oxygen
                 palette.setColor( QPalette::Window, mixed );
                 palette.setColor( QPalette::Button, mixed );
 
-            } else if( isActive() || isForcedActive() ) {
+            } else {
 
-                const QColor color =  options()->color( KDecorationDefines::ColorTitleBar, true );
-                palette.setColor( QPalette::Window, color );
-                palette.setColor( QPalette::Button, color );
+                const QColor background( options()->color( KDecorationDefines::ColorTitleBar, isActive() || isForcedActive() ) );
+                palette.setColor( QPalette::Window, background );
+                palette.setColor( QPalette::Button, background );
+
+                const QColor foreground( options()->color( KDecorationDefines::ColorFont, isActive() || isForcedActive() ) );
+                palette.setColor( QPalette::WindowText, foreground );
+                palette.setColor( QPalette::ButtonText, foreground );
 
             }
 
@@ -1543,7 +1558,7 @@ namespace Oxygen
         QRect frame = widget()->rect();
 
         // base color
-        QColor color = palette.window().color();
+        QColor color = palette.color( QPalette::Window );
 
         // draw shadows
         if( compositingActive() && shadowCache().shadowSize() > 0 && !isMaximized() )
@@ -1958,11 +1973,22 @@ namespace Oxygen
         // mask
         painter.setClipRegion( helper().roundedMask( geometry ), Qt::IntersectClip );
 
-        // render window background
-        renderWindowBackground( &painter, geometry, widget(), widget()->palette() );
-
         // darken background if item is inactive
         const bool itemActive = (tabCount() <= 1) || !( itemValid && tabId(index) != currentTabId() );
+        QPalette palette( widget()->palette() );
+
+        if( _configuration->drawTitleOutline() && !itemActive )
+        {
+
+            const QColor color =  options()->color( KDecorationDefines::ColorTitleBar, isActive() );
+            palette.setColor( QPalette::Window, color );
+            palette.setColor( QPalette::Button, color );
+
+        }
+
+        // render window background
+        renderWindowBackground( &painter, geometry, widget(), palette );
+
         if( !itemActive )
         {
 
@@ -1986,8 +2012,8 @@ namespace Oxygen
 
         renderTitleText(
             &painter, textRect, caption,
-            titlebarTextColor( widget()->palette(), isActive() && itemActive ),
-            titlebarContrastColor( widget()->palette() ) );
+            titlebarTextColor( palette, isActive(), itemActive ),
+            titlebarContrastColor( palette ) );
 
         // adjust geometry for floatFrame when compositing is on.
         if( drawShadow )
@@ -1995,7 +2021,7 @@ namespace Oxygen
 
         // floating frame
         helper().drawFloatFrame(
-            &painter, geometry, widget()->palette().window().color(),
+            &painter, geometry, palette.color( QPalette::Window ),
             !drawShadow, false,
             KDecoration::options()->color(ColorTitleBar)
             );
